history

# XMLRésuméLibrary: User Guide

header | Element Reference | instantMessage

## Name

history — Container for a person's previous (and possibly current) jobs

## Synopsis

### Content Model

    (job+)

### Attributes

Name | Type | Default
--- | --- | ---
targets | CDATA | None

## Description

The `history` element contains a person's job history (the jobs that they have worked at in the past). It is also common to include their current job in this element.

### Parents

`history` may be contained in these elements: `resume`

## Examples

    <history>
      <job>
        <jobtitle>Counselor</jobtitle>
        <employer>Shrink Inc.</employer>
        <period>
          <from><date><month>August</month><year>1490</year></date></from>
          <to><date><month>January</month><year>1497</year></date></to>
        </period>
        <description>
          <para>
            Counseled King Ferdinand and Queen Isabella. Helped to calm their fears
            about their large investment in a man named Christopher Columbus.
          </para>
          <para>
            When Columbus returned with gold, I was "downsized" by beheading.
          </para>
        </description>
      </job>
      <job>
        <jobtitle>Angel</jobtitle>
        <employer>Heaven</employer>
        <period>
          <from><date><month>January</month><year>1497</year></date></from>
          <to><date><month>June</month><year>2344</year></date></to>
        </period>
        <description>
          <para>
            Saved souls.
          </para>
        </description>
      </job>
      <job>
        <jobtitle>Supersonic Vacuum Technician</jobtitle>
        <employer>Joe's Vacuum Shop</employer>
        <period>
          <from><date><month>June</month><year>2344</year></date></from>
          <to><present/></to>
        </period>
        <description>
          <para>
            Allowed to return to earth to help my great-great-great-(you get the
            picture)-grandson Joe with his business.
          </para>
          <para>
            Repaired hyperdynamic microbial neutron particle accelerators in
            Supersonic vacuum models XL144 and XP2000.
          </para>
        </description>
      </job>
    </history>

header | Element Reference | instantMessage